@@ -1,5 +1,5 @@
 #!/usr/bin/python
-'''データベースのドライバ
+"""データベースのドライバ
 
     * sqlalchemyのデータベースエンジンを返す関数が入ってる
     * ぶっちゃけ、sqlite以外に対応する気はあんまりない
@@ -8,4 +8,4 @@
     * get_engine関数がユーザー管理用データベースのエンジンを返す
     * get_test_engine関数がユーザー管理用データベースのテスト用エンジンを返す
     * get_app_engine関数がアプリのデータベースのエンジンを返す(sqlite限定)
-'''
+"""
