@@ -5,7 +5,7 @@ from mitama.models import User
 
 class InitializeMiddleware(Middleware):
     def process(self, request, handler):
-        if User.query.count() == 0:
+        if User.query.filter(User.password != None).count() == 0:
             return Response.redirect(self.app.convert_url("/setup"))
         else:
             return handler(request)
